lcvtoolbox.core.schemas.FrameMetadata
=====================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: FrameMetadata
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~FrameMetadata.__init__
      ~FrameMetadata.construct
      ~FrameMetadata.copy
      ~FrameMetadata.dict
      ~FrameMetadata.from_orm
      ~FrameMetadata.json
      ~FrameMetadata.model_construct
      ~FrameMetadata.model_copy
      ~FrameMetadata.model_dump
      ~FrameMetadata.model_dump_json
      ~FrameMetadata.model_json_schema
      ~FrameMetadata.model_parametrized_name
      ~FrameMetadata.model_post_init
      ~FrameMetadata.model_rebuild
      ~FrameMetadata.model_validate
      ~FrameMetadata.model_validate_json
      ~FrameMetadata.model_validate_strings
      ~FrameMetadata.parse_file
      ~FrameMetadata.parse_obj
      ~FrameMetadata.parse_raw
      ~FrameMetadata.schema
      ~FrameMetadata.schema_json
      ~FrameMetadata.update_forward_refs
      ~FrameMetadata.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FrameMetadata.gps_point
      ~FrameMetadata.model_computed_fields
      ~FrameMetadata.model_config
      ~FrameMetadata.model_extra
      ~FrameMetadata.model_fields
      ~FrameMetadata.model_fields_set
      ~FrameMetadata.time
      ~FrameMetadata.latitude
      ~FrameMetadata.longitude
      ~FrameMetadata.altitude
      ~FrameMetadata.orientation
      ~FrameMetadata.images
   
   